@@ -11,25 +11,24 @@ class Bookmark
     end
 
     def == (other)
-        return false if other == nil
-        return ( @buffer == other.buffer and @row == other.row and @col == other.col )
+        return false if other.nil?
+        ( @buffer == other.buffer and @row == other.row and @col == other.col )
     end
 
     def <=> (other)
-        return nil if other == nil
+        return nil if other.nil?
         comparison = ( $diakonos.bufferToNumber( @buffer ) <=> $diakonos.bufferToNumber( other.buffer ) )
         return comparison if comparison != 0
         comparison = ( @row <=> other.row )
         return comparison if comparison != 0
-        comparison = ( @col <=> other.col )
-        return comparison
+        @col <=> other.col
     end
 
     def < (other)
-        return ( ( self <=> other ) < 0 )
+        ( ( self <=> other ) < 0 )
     end
     def > (other)
-        return ( ( self <=> other ) > 0 )
+        ( ( self <=> other ) > 0 )
     end
     
     def incRow( increment )
@@ -44,7 +43,7 @@ class Bookmark
     end
 
     def to_s
-        return "[#{@name}|#{@buffer.name}:#{@row+1},#{@col+1}]"
+        "[#{@name}|#{@buffer.name}:#{@row+1},#{@col+1}]"
     end
 end
 
