@@ -6,10 +6,10 @@ module Enumerable
             element.scan( regexp ) do |match_text|
                 match = Regexp.last_match
                 strindex = match.begin( 0 )
-                array.push [ index, strindex, strindex + match_text.length ]
+                array.push [ index, strindex, strindex + match[ 0 ].length ]
             end
         end
-        return array
+        array
     end
 end
 
