@@ -1,6 +1,6 @@
 class Regexp
     def uses_bos
-        return ( source[ 0 ] == ?^ )
+        source[ 0 ] == ?^
     end
 end
 
